References
==========

The creation of DebOps wouldn't be possible without massive amounts of
documentation, knowledge and know-how present on the Internet. Many solutions
to problems encountered during the development have been found on various
blogs, HOWTOs and other documentation, it would be hard to list them all.
However, there are some notable entries which you can use for reference during
the development of your own IT infrastructure.


`The Debian Administrator's Handbook`__
---------------------------------------

.. __: https://debian-handbook.info/

This is a very accessible book about the Debian Project and Debian OS
administration, written by the project's Developers. Highly recommended for
beginners.


`The Debian Project documentation`__
------------------------------------

.. __: https://www.debian.org/doc/

A reference page with huge amount of documentation sources related to Debian
GNU/Linux operating system.


`ArchWiki`__
------------

.. __: https://wiki.archlinux.org/

The official wiki of the `Arch Linux`__ distribution, maintained by its users.
The operating system itself might be different, however many software packages
are present both in Debian as well as Arch, and solutions found on the wiki are
usually easily applicable to Debian hosts.

.. __: https://www.archlinux.org/


`The Twelve-Factor App`__
-------------------------

.. __: https://12factor.net/

This page provides a look at a modern application deployment and configuration
stack. Its meant more for developers than administrators, however it might be
an useful window to see what might be expected from the IT infrastructure you
are managing.


`Computing Infrastructure Setup Protocols`__
--------------------------------------------

.. __: http://infrastructure.blueprint.org/

Orderly deployment of cost-effective and scalable computing infrastructure for
life-science research groups. Yao M, Luo W, and Hogue C.W.V. (2009)  JOURNAL VOL:PP


`Infrastructures.Org`__
-----------------------

.. __: http://www.infrastructures.org/

This is an older website which discusses good practices for IT infrastructure
deployment. The technologies used are ancient from the perspective of the IT
departments today, however the methodology used during the deployment might
still be useful and relevant.


`Ops School Curriculum`__
-------------------------

.. __: http://www.opsschool.org/

This site provides a general information and introduction to IT Operations and
explains what Operations Enginners do. The documentation is presented as
a curriculum with lessons on different topics.


`Larg's Internet Cluster`__
---------------------------

.. __: https://web.archive.org/web/20160613213246/http://www.planetlarg.net:80/

This is a website with description of the build process of an Internet Cluster.
The `original website`__ seems to be gone, however the `Web Archive`__ version is
available.

.. __: http://www.planetlarg.net/
.. __: https://web.archive.org/


`Research Computing at Imperial College London`__
-------------------------------------------------

.. __: http://www.imperial.ac.uk/mathematics/for-staff/research-computing-support/

This is a homepage of the Department of Mathematics at ICL. They have their own
HPC infrastructure `with extensive documentation`__, aimed mostly at their
users, however it might be useful to see how the IT infrastructure looks from
the user side.

.. __: http://sysnews.ma.ic.ac.uk/
